@@ -179,7 +179,7 @@ RecordBase::create(ESM::NAME type)
 {
     RecordBase *record = 0;
 
-    switch (type.val) {
+    switch (type.intval) {
     case ESM::REC_ACTI:
     {
         record = new EsmTool::Record<ESM::Activator>;
