@@ -29,6 +29,9 @@
 #include "soundgencheck.hpp"
 #include "magiceffectcheck.hpp"
 #include "mergeoperation.hpp"
+#include "gmstcheck.hpp"
+#include "topicinfocheck.hpp"
+#include "journalcheck.hpp"
 
 CSMDoc::OperationHolder *CSMTools::Tools::get (int type)
 {
@@ -111,6 +114,23 @@ CSMDoc::OperationHolder *CSMTools::Tools::getVerifier()
                                                                     mData.getResources (CSMWorld::UniversalId::Type_Icons),
                                                                     mData.getResources (CSMWorld::UniversalId::Type_Textures)));
 
+        mVerifierOperation->appendStage (new GmstCheckStage (mData.getGmsts()));
+
+        mVerifierOperation->appendStage (new TopicInfoCheckStage (mData.getTopicInfos(),
+                                                                  mData.getCells(),
+                                                                  mData.getClasses(),
+                                                                  mData.getFactions(),
+                                                                  mData.getGmsts(),
+                                                                  mData.getGlobals(),
+                                                                  mData.getJournals(),
+                                                                  mData.getRaces(),
+                                                                  mData.getRegions(),
+                                                                  mData.getTopics(),
+                                                                  mData.getReferenceables().getDataSet(),
+                                                                  mData.getResources (CSMWorld::UniversalId::Type_SoundsRes)));
+
+        mVerifierOperation->appendStage (new JournalCheckStage(mData.getJournals(), mData.getJournalInfos()));
+
         mVerifier.setOperation (mVerifierOperation);
     }
 
