@@ -53,6 +53,10 @@ namespace CSMWorld
             void addRecord (const std::string& id, UniversalId::Type type = UniversalId::Type_None);
             ///< \param type Will be ignored, unless the collection supports multiple record types
 
+            void addRecordWithData (const std::string& id, const std::map<int, QVariant>& data,
+                UniversalId::Type type = UniversalId::Type_None);
+            ///< \param type Will be ignored, unless the collection supports multiple record types
+
             void cloneRecord(const std::string& origin,
                              const std::string& destination,
                              UniversalId::Type type = UniversalId::Type_None);
