@@ -19,6 +19,7 @@
 
 #include "editmode.hpp"
 #include "mask.hpp"
+#include "cameracontroller.hpp"
 
 bool CSVRender::PagedWorldspaceWidget::adjustCells()
 {
@@ -512,12 +513,15 @@ void CSVRender::PagedWorldspaceWidget::useViewHint (const std::string& hint)
             {
                 char ignore1; // : or ;
                 char ignore2; // #
+                // Current coordinate
                 int x, y;
 
+                // Loop throught all the coordinates to add them to selection
                 while (stream >> ignore1 >> ignore2 >> x >> y)
                     selection.add (CSMWorld::CellCoordinates (x, y));
-
-                /// \todo adjust camera position
+                               
+                // Mark that camera needs setup
+                mCamPositionSet=false;
             }
         }
         else if (hint[0]=='r')
@@ -554,18 +558,18 @@ std::pair< int, int > CSVRender::PagedWorldspaceWidget::getCoordinatesFromId (co
 }
 
 bool CSVRender::PagedWorldspaceWidget::handleDrop (
-    const std::vector< CSMWorld::UniversalId >& data, DropType type)
+    const std::vector< CSMWorld::UniversalId >& universalIdData, DropType type)
 {
-    if (WorldspaceWidget::handleDrop (data, type))
+    if (WorldspaceWidget::handleDrop (universalIdData, type))
         return true;
 
     if (type!=Type_CellsExterior)
         return false;
 
     bool selectionChanged = false;
-    for (unsigned i = 0; i < data.size(); ++i)
+    for (unsigned i = 0; i < universalIdData.size(); ++i)
     {
-        std::pair<int, int> coordinates(getCoordinatesFromId(data[i].getId()));
+        std::pair<int, int> coordinates(getCoordinatesFromId(universalIdData[i].getId()));
         if (mSelection.add(CSMWorld::CellCoordinates(coordinates.first, coordinates.second)))
         {
             selectionChanged = true;
