@@ -146,9 +146,6 @@ namespace MWClass
 
         float epsilon = 0.0005f;
 
-        if (ref->mBase->mData.mWeight == 0)
-            return ESM::Skill::Unarmored;
-
         if (ref->mBase->mData.mWeight <= iWeight * gmst.find ("fLightMaxMod")->getFloat() + epsilon)
             return ESM::Skill::LightArmor;
 
@@ -220,14 +217,19 @@ namespace MWClass
         std::string text;
 
         // get armor type string (light/medium/heavy)
-        int armorType = getEquipmentSkill(ptr);
         std::string typeText;
-        if (armorType == ESM::Skill::LightArmor)
-            typeText = "#{sLight}";
-        else if (armorType == ESM::Skill::MediumArmor)
-            typeText = "#{sMedium}";
+        if (ref->mBase->mData.mWeight == 0)
+            typeText = "";
         else
-            typeText = "#{sHeavy}";
+        {
+            int armorType = getEquipmentSkill(ptr);       
+            if (armorType == ESM::Skill::LightArmor)
+                typeText = "#{sLight}";
+            else if (armorType == ESM::Skill::MediumArmor)
+                typeText = "#{sMedium}";
+            else
+                typeText = "#{sHeavy}";
+        }
 
         text += "\n#{sArmorRating}: " + MWGui::ToolTips::toString(getEffectiveArmorRating(ptr,
             MWMechanics::getPlayer()));
@@ -236,7 +238,9 @@ namespace MWClass
         text += "\n#{sCondition}: " + MWGui::ToolTips::toString(remainingHealth) + "/"
                 + MWGui::ToolTips::toString(ref->mBase->mData.mHealth);
 
-        text += "\n#{sWeight}: " + MWGui::ToolTips::toString(ref->mBase->mData.mWeight) + " (" + typeText + ")";
+        if (typeText != "")
+            text += "\n#{sWeight}: " + MWGui::ToolTips::toString(ref->mBase->mData.mWeight) + " (" + typeText + ")";
+
         text += MWGui::ToolTips::getValueString(ref->mBase->mData.mValue, "#{sValue}");
 
         if (MWBase::Environment::get().getWindowManager()->getFullHelp()) {
