@@ -70,6 +70,9 @@ namespace MWGui
         virtual MWWorld::Ptr copyItem (const ItemStack& item, size_t count, bool setNewOwner=false) = 0;
         virtual void removeItem (const ItemStack& item, size_t count) = 0;
 
+        /// Is the player allowed to insert items into this model? (default true)
+        virtual bool allowedToInsertItems() const;
+
     private:
         ItemModel(const ItemModel&);
         ItemModel& operator=(const ItemModel&);
