@@ -109,6 +109,7 @@
 #include "container.hpp"
 #include "controllers.hpp"
 #include "jailscreen.hpp"
+#include "itemchargeview.hpp"
 
 namespace MWGui
 {
@@ -223,6 +224,7 @@ namespace MWGui
         MyGUI::FactoryManager::getInstance().registerFactory<osgMyGUI::ScalingLayer>("Layer");
         BookPage::registerMyGUIComponents ();
         ItemView::registerComponents();
+        ItemChargeView::registerComponents();
         ItemWidget::registerComponents();
         SpellView::registerComponents();
         Gui::registerAllWidgets();
@@ -282,7 +284,7 @@ namespace MWGui
 
         mRecharge = new Recharge();
         mMenu = new MainMenu(w, h, mResourceSystem->getVFS(), mVersionDescription);
-        mLocalMapRender = new MWRender::LocalMap(mViewer);
+        mLocalMapRender = new MWRender::LocalMap(mViewer->getSceneData()->asGroup());
         mMap = new MapWindow(mCustomMarkers, mDragAndDrop, mLocalMapRender);
         trackWindow(mMap, "map");
         mStatsWindow = new StatsWindow(mDragAndDrop);
@@ -293,7 +295,7 @@ namespace MWGui
         bool questList = mResourceSystem->getVFS()->exists("textures/tx_menubook_options_over.dds");
         mJournal = JournalWindow::create(JournalViewModel::create (), questList);
         mMessageBoxManager = new MessageBoxManager(mStore->get<ESM::GameSetting>().find("fMessageTimePerChar")->getFloat());
-        mInventoryWindow = new InventoryWindow(mDragAndDrop, mViewer, mResourceSystem);
+        mInventoryWindow = new InventoryWindow(mDragAndDrop, mViewer->getSceneData()->asGroup(), mResourceSystem);
         mTradeWindow = new TradeWindow();
         trackWindow(mTradeWindow, "barter");
         mSpellBuyingWindow = new SpellBuyingWindow();
@@ -350,7 +352,7 @@ namespace MWGui
 
         mHud->setVisible(mHudEnabled);
 
-        mCharGen = new CharacterCreation(mViewer, mResourceSystem);
+        mCharGen = new CharacterCreation(mViewer->getSceneData()->asGroup(), mResourceSystem);
 
         // Setup player stats
         for (int i = 0; i < ESM::Attribute::Length; ++i)
@@ -384,7 +386,7 @@ namespace MWGui
         {
             disallowAll();
             delete mCharGen;
-            mCharGen = new CharacterCreation(mViewer, mResourceSystem);
+            mCharGen = new CharacterCreation(mViewer->getSceneData()->asGroup(), mResourceSystem);
             mGuiModes.clear();
             MWBase::Environment::get().getInputManager()->changeInputMode(false);
             mHud->unsetSelectedWeapon();
@@ -1004,6 +1006,9 @@ namespace MWGui
         mScreenFader->update(frameDuration);
 
         mDebugWindow->onFrame(frameDuration);
+
+        if (mCharGen)
+            mCharGen->onFrame(frameDuration);
     }
 
     void WindowManager::changeCell(const MWWorld::CellStore* cell)
