@@ -55,19 +55,18 @@ namespace MWMechanics
             virtual bool canCancel() const { return false; }
             virtual bool shouldCancelPreviousAi() const { return false; }
 
-        protected:
-            virtual bool doesPathNeedRecalc(ESM::Pathgrid::Point dest, const ESM::Cell *cell);
-
         private:
 
             int mTargetActorId;
 
-            void buildNewPath(const MWWorld::Ptr& actor, const MWWorld::Ptr& target);
-            bool reactionTimeActions(const MWWorld::Ptr& actor, CharacterController& characterController,
-                AiCombatStorage& storage, MWWorld::Ptr target);
+            void attack(const MWWorld::Ptr& actor, const MWWorld::Ptr& target, AiCombatStorage& storage, CharacterController& characterController);
+
+            void updateLOS(const MWWorld::Ptr& actor, const MWWorld::Ptr& target, float duration, AiCombatStorage& storage);
+
+            void updateFleeing(const MWWorld::Ptr& actor, const MWWorld::Ptr& target, float duration, AiCombatStorage& storage);
 
             /// Transfer desired movement (from AiCombatStorage) to Actor
-            void updateActorsMovement(const MWWorld::Ptr& actor, float duration, MWMechanics::Movement& movement);
+            void updateActorsMovement(const MWWorld::Ptr& actor, float duration, AiCombatStorage& storage);
             void rotateActorOnAxis(const MWWorld::Ptr& actor, int axis, 
                 MWMechanics::Movement& actorMovementSettings, MWMechanics::Movement& desiredMovement);
     };
