@@ -29,7 +29,6 @@ namespace MWMechanics
 {
     static const int COUNT_BEFORE_RESET = 10;
     static const float DOOR_CHECK_INTERVAL = 1.5f;
-    static const float REACTION_INTERVAL = 0.25f;
     static const int GREETING_SHOULD_START = 4; //how many reaction intervals should pass before NPC can greet player
     static const int GREETING_SHOULD_END = 10;
 
@@ -74,8 +73,6 @@ namespace MWMechanics
         unsigned short mIdleAnimation;
         std::vector<unsigned short> mBadIdles; // Idle animations that when called cause errors
 
-        PathFinder mPathFinder;
-
         // do we need to calculate allowed nodes based on mDistance
         bool mPopulateAvailableNodes;
 
@@ -86,8 +83,6 @@ namespace MWMechanics
         ESM::Pathgrid::Point mCurrentNode;
         bool mTrimCurrentNode;
 
-        ObstacleCheck mObstacleCheck;
-
         float mDoorCheckDuration;
         int mStuckCount;
         
@@ -196,7 +191,6 @@ namespace MWMechanics
     {
         // get or create temporary storage
         AiWanderStorage& storage = state.get<AiWanderStorage>();
-        
 
         const MWWorld::CellStore*& currentCell = storage.mCell;
         MWMechanics::CreatureStats& cStats = actor.getClass().getCreatureStats(actor);
@@ -206,6 +200,7 @@ namespace MWMechanics
         bool cellChange = currentCell && (actor.getCell() != currentCell);
         if(!currentCell || cellChange)
         {
+            stopWalking(actor, storage);
             currentCell = actor.getCell();
             storage.mPopulateAvailableNodes = true;
         }
@@ -223,7 +218,7 @@ namespace MWMechanics
 
         float& lastReaction = storage.mReaction;
         lastReaction += duration;
-        if (REACTION_INTERVAL <= lastReaction)
+        if (AI_REACTION_TIME <= lastReaction)
         {
             lastReaction = 0;
             return reactionTimeActions(actor, storage, currentCell, cellChange, pos, duration);
@@ -273,7 +268,7 @@ namespace MWMechanics
         }
 
         // If Wandering manually and hit an obstacle, stop
-        if (storage.mIsWanderingManually && storage.mObstacleCheck.check(actor, duration, 2.0f)) {
+        if (storage.mIsWanderingManually && mObstacleCheck.check(actor, duration, 2.0f)) {
             completeManualWalking(actor, storage);
         }
 
@@ -300,14 +295,14 @@ namespace MWMechanics
         if ((wanderState == Wander_MoveNow) && storage.mCanWanderAlongPathGrid)
         {
             // Construct a new path if there isn't one
-            if(!storage.mPathFinder.isPathConstructed())
+            if(!mPathFinder.isPathConstructed())
             {
                 if (!storage.mAllowedNodes.empty())
                 {
                     setPathToAnAllowedNode(actor, storage, pos);
                 }
             } 
-        } else if (storage.mIsWanderingManually && storage.mPathFinder.checkPathCompleted(pos.pos[0], pos.pos[1], DESTINATION_TOLERANCE)) {
+        } else if (storage.mIsWanderingManually && mPathFinder.checkPathCompleted(pos.pos[0], pos.pos[1], DESTINATION_TOLERANCE)) {
             completeManualWalking(actor, storage);
         }
 
@@ -337,7 +332,7 @@ namespace MWMechanics
 
     void AiWander::returnToStartLocation(const MWWorld::Ptr& actor, AiWanderStorage& storage, ESM::Position& pos)
     {
-        if (!storage.mPathFinder.isPathConstructed())
+        if (!mPathFinder.isPathConstructed())
         {
             ESM::Pathgrid::Point dest(PathFinder::MakePathgridPoint(mReturnPosition));
 
@@ -345,9 +340,9 @@ namespace MWMechanics
             ESM::Pathgrid::Point start(PathFinder::MakePathgridPoint(pos));
 
             // don't take shortcuts for wandering
-            storage.mPathFinder.buildSyncedPath(start, dest, actor.getCell(), false);
+            mPathFinder.buildSyncedPath(start, dest, actor.getCell());
 
-            if (storage.mPathFinder.isPathConstructed())
+            if (mPathFinder.isPathConstructed())
             {
                 storage.setState(Wander_Walking);
             }
@@ -379,9 +374,13 @@ namespace MWMechanics
             // Check if land creature will walk onto water or if water creature will swim onto land
             if ((!isWaterCreature && !destinationIsAtWater(actor, destination)) ||
                 (isWaterCreature && !destinationThroughGround(currentPositionVec3f, destination))) {
-                storage.mPathFinder.buildSyncedPath(currentPosition, destinationPosition, actor.getCell(), true);
-                storage.mPathFinder.addPointToPath(destinationPosition);
-                storage.setState(Wander_Walking, true);
+                mPathFinder.buildSyncedPath(currentPosition, destinationPosition, actor.getCell());
+                mPathFinder.addPointToPath(destinationPosition);
+
+                if (mPathFinder.isPathConstructed())
+                {
+                    storage.setState(Wander_Walking, true);
+                }
                 return;
             }
         } while (--attempts);
@@ -407,7 +406,7 @@ namespace MWMechanics
 
     void AiWander::completeManualWalking(const MWWorld::Ptr &actor, AiWanderStorage &storage) {
         stopWalking(actor, storage);
-        storage.mObstacleCheck.clear();
+        mObstacleCheck.clear();
         storage.setState(Wander_IdleNow);
     }
 
@@ -475,7 +474,7 @@ namespace MWMechanics
         float duration, AiWanderStorage& storage, ESM::Position& pos)
     {
         // Are we there yet?
-        if (storage.mPathFinder.checkPathCompleted(pos.pos[0], pos.pos[1], DESTINATION_TOLERANCE))
+        if (pathTo(actor, mPathFinder.getPath().back(), duration, DESTINATION_TOLERANCE))
         {
             stopWalking(actor, storage);
             storage.setState(Wander_ChooseAction);
@@ -517,40 +516,27 @@ namespace MWMechanics
 
     void AiWander::evadeObstacles(const MWWorld::Ptr& actor, AiWanderStorage& storage, float duration, ESM::Position& pos)
     {
-        // turn towards the next point in mPath
-        zTurn(actor, storage.mPathFinder.getZAngleToNext(pos.pos[0], pos.pos[1]));
-
-        MWMechanics::Movement& movement = actor.getClass().getMovementSettings(actor);
-        if (storage.mObstacleCheck.check(actor, duration))
+        if (mObstacleCheck.isEvading())
         {
             // first check if we're walking into a door
             if (proximityToDoor(actor)) // NOTE: checks interior cells only
             {
                 // remove allowed points then select another random destination
                 storage.mTrimCurrentNode = true;
-                trimAllowedNodes(storage.mAllowedNodes, storage.mPathFinder);
-                storage.mObstacleCheck.clear();
-                storage.mPathFinder.clearPath();
+                trimAllowedNodes(storage.mAllowedNodes, mPathFinder);
+                mObstacleCheck.clear();
+                mPathFinder.clearPath();
                 storage.setState(Wander_MoveNow);
             }
-            else // probably walking into another NPC
-            {
-                // TODO: diagonal should have same animation as walk forward
-                //       but doesn't seem to do that?
-                storage.mObstacleCheck.takeEvasiveAction(movement);
-            }
-            storage.mStuckCount++;  // TODO: maybe no longer needed
-        }
-        else
-        {
-            movement.mPosition[1] = 1;
+
+           storage.mStuckCount++;  // TODO: maybe no longer needed
         }
 
         // if stuck for sufficiently long, act like current location was the destination
         if (storage.mStuckCount >= COUNT_BEFORE_RESET) // something has gone wrong, reset
         {
             //std::cout << "Reset \""<< cls.getName(actor) << "\"" << std::endl;
-            storage.mObstacleCheck.clear();
+            mObstacleCheck.clear();
 
             stopWalking(actor, storage);
             storage.setState(Wander_ChooseAction);
@@ -627,7 +613,7 @@ namespace MWMechanics
             if (storage.mState == Wander_Walking)
             {
                 stopWalking(actor, storage);
-                storage.mObstacleCheck.clear();
+                mObstacleCheck.clear();
                 storage.setState(Wander_IdleNow);
             }
 
@@ -667,9 +653,9 @@ namespace MWMechanics
         ESM::Pathgrid::Point start(PathFinder::MakePathgridPoint(actorPos));
 
         // don't take shortcuts for wandering
-        storage.mPathFinder.buildSyncedPath(start, dest, actor.getCell(), false);
+        mPathFinder.buildSyncedPath(start, dest, actor.getCell());
 
-        if (storage.mPathFinder.isPathConstructed())
+        if (mPathFinder.isPathConstructed())
         {
             // Remove this node as an option and add back the previously used node (stops NPC from picking the same node):
             ESM::Pathgrid::Point temp = storage.mAllowedNodes[randNode];
@@ -726,7 +712,7 @@ namespace MWMechanics
 
     void AiWander::stopWalking(const MWWorld::Ptr& actor, AiWanderStorage& storage)
     {
-        storage.mPathFinder.clearPath();
+        mPathFinder.clearPath();
         actor.getClass().getMovementSettings(actor).mPosition[1] = 0;
     }
 
@@ -812,9 +798,6 @@ namespace MWMechanics
         MWBase::Environment::get().getWorld()->moveObject(actor, static_cast<float>(dest.mX), 
             static_cast<float>(dest.mY), static_cast<float>(dest.mZ));
         actor.getClass().adjustPosition(actor, false);
-
-        // may have changed cell
-        storage.mPopulateAvailableNodes = true;
     }
 
     int AiWander::OffsetToPreventOvercrowding()
