@@ -6,8 +6,8 @@
 #include <osg/Texture2D>
 #include <osg/Camera>
 #include <osg/PositionAttitudeTransform>
-#include <osgViewer/Viewer>
 #include <osg/LightModel>
+#include <osg/LightSource>
 #include <osgUtil/IntersectionVisitor>
 #include <osgUtil/LineSegmentIntersector>
 
@@ -65,9 +65,9 @@ namespace MWRender
         unsigned int mLastRenderedFrame;
     };
 
-    CharacterPreview::CharacterPreview(osgViewer::Viewer* viewer, Resource::ResourceSystem* resourceSystem,
+    CharacterPreview::CharacterPreview(osg::Group* parent, Resource::ResourceSystem* resourceSystem,
                                        MWWorld::Ptr character, int sizeX, int sizeY, const osg::Vec3f& position, const osg::Vec3f& lookAt)
-        : mViewer(viewer)
+        : mParent(parent)
         , mResourceSystem(resourceSystem)
         , mPosition(position)
         , mLookAt(lookAt)
@@ -93,7 +93,6 @@ namespace MWRender
         mCamera->setViewport(0, 0, sizeX, sizeY);
         mCamera->setRenderOrder(osg::Camera::PRE_RENDER);
         mCamera->attach(osg::Camera::COLOR_BUFFER, mTexture);
-        mCamera->setGraphicsContext(mViewer->getCamera()->getGraphicsContext());
 
         mCamera->setNodeMask(Mask_RenderToTexture);
 
@@ -140,14 +139,15 @@ namespace MWRender
         mDrawOnceCallback = new DrawOnceCallback;
         mCamera->addUpdateCallback(mDrawOnceCallback);
 
-        mViewer->getSceneData()->asGroup()->addChild(mCamera);
+        mParent->addChild(mCamera);
 
         mCharacter.mCell = NULL;
     }
 
     CharacterPreview::~CharacterPreview ()
     {
-        mViewer->getSceneData()->asGroup()->removeChild(mCamera);
+        mCamera->removeChildren(0, mCamera->getNumChildren());
+        mParent->removeChild(mCamera);
     }
 
     int CharacterPreview::getTextureWidth() const
@@ -190,8 +190,8 @@ namespace MWRender
     // --------------------------------------------------------------------------------------------------
 
 
-    InventoryPreview::InventoryPreview(osgViewer::Viewer* viewer, Resource::ResourceSystem* resourceSystem, MWWorld::Ptr character)
-        : CharacterPreview(viewer, resourceSystem, character, 512, 1024, osg::Vec3f(0, 700, 71), osg::Vec3f(0,0,71))
+    InventoryPreview::InventoryPreview(osg::Group* parent, Resource::ResourceSystem* resourceSystem, MWWorld::Ptr character)
+        : CharacterPreview(parent, resourceSystem, character, 512, 1024, osg::Vec3f(0, 700, 71), osg::Vec3f(0,0,71))
     {
     }
 
@@ -221,10 +221,10 @@ namespace MWRender
             groupname = "inventoryhandtohand";
         else
         {
-            const std::string &type = iter->getTypeName();
-            if(type == typeid(ESM::Lockpick).name() || type == typeid(ESM::Probe).name())
+            const std::string &typeName = iter->getTypeName();
+            if(typeName == typeid(ESM::Lockpick).name() || typeName == typeid(ESM::Probe).name())
                 groupname = "inventoryweapononehand";
-            else if(type == typeid(ESM::Weapon).name())
+            else if(typeName == typeid(ESM::Weapon).name())
             {
                 MWWorld::LiveCellRef<ESM::Weapon> *ref = iter->get<ESM::Weapon>();
 
@@ -319,8 +319,8 @@ namespace MWRender
 
     // --------------------------------------------------------------------------------------------------
 
-    RaceSelectionPreview::RaceSelectionPreview(osgViewer::Viewer* viewer, Resource::ResourceSystem* resourceSystem)
-        : CharacterPreview(viewer, resourceSystem, MWMechanics::getPlayer(),
+    RaceSelectionPreview::RaceSelectionPreview(osg::Group* parent, Resource::ResourceSystem* resourceSystem)
+        : CharacterPreview(parent, resourceSystem, MWMechanics::getPlayer(),
             512, 512, osg::Vec3f(0, 125, 8), osg::Vec3f(0,0,8))
         , mBase (*mCharacter.get<ESM::NPC>()->mBase)
         , mRef(&mBase)
