@@ -1329,7 +1329,7 @@ void SkyManager::createRain()
     mRainParticleSystem = new osgParticle::ParticleSystem;
     mRainParticleSystem->setParticleAlignment(osgParticle::ParticleSystem::FIXED);
     mRainParticleSystem->setAlignVectorX(osg::Vec3f(0.1,0,0));
-    mRainParticleSystem->setAlignVectorY(osg::Vec3f(0,0,-1));
+    mRainParticleSystem->setAlignVectorY(osg::Vec3f(0,0,1));
 
     osg::ref_ptr<osg::StateSet> stateset (mRainParticleSystem->getOrCreateStateSet());
 
