@@ -212,7 +212,7 @@ namespace MWWorld
 
         MWWorld::Ptr player = getPlayer();
         const MWMechanics::NpcStats &playerStats = player.getClass().getNpcStats(player);
-        if (playerStats.isParalyzed() || playerStats.getKnockedDown())
+        if (playerStats.isParalyzed() || playerStats.getKnockedDown() || playerStats.isDead())
             return;
 
         MWWorld::Ptr toActivate = MWBase::Environment::get().getWorld()->getFacedObject();
@@ -220,17 +220,9 @@ namespace MWWorld
         if (toActivate.isEmpty())
             return;
 
-        if (toActivate.getClass().getName(toActivate) == "") // objects without name presented to user can never be activated
+        if (!toActivate.getClass().canBeActivated(toActivate))
             return;
 
-        if (toActivate.getClass().isActor())
-        {
-            MWMechanics::CreatureStats &stats = toActivate.getClass().getCreatureStats(toActivate);
-
-            if (stats.getAiSequence().isInCombat() && !stats.isDead())
-                return;
-        }
-
         MWBase::Environment::get().getWorld()->activate(toActivate, player);
     }
 
