@@ -1,7 +1,5 @@
 #include "visitor.hpp"
 
-#include <osg/Geode>
-
 #include <osgParticle/ParticleSystem>
 
 #include <components/misc/stringops.hpp>
@@ -19,12 +17,6 @@ namespace SceneUtil
         traverse(group);
     }
 
-    void DisableFreezeOnCullVisitor::apply(osg::Geode &geode)
-    {
-        for (unsigned int i=0; i<geode.getNumDrawables(); ++i)
-            apply(*geode.getDrawable(i));
-    }
-
     void DisableFreezeOnCullVisitor::apply(osg::Drawable& drw)
     {
         if (osgParticle::ParticleSystem* partsys = dynamic_cast<osgParticle::ParticleSystem*>(&drw))
